# magyar


## Leírás

Magyar listák gyűjteménye - Collection of Hungarian lists.

Az alábbi listákat találod :
1. vezetéknevek   =  magyar.vezeteknev
2. női keresztnevek  = magyar.keresztnev_n
3. férfi keresztnevek = magyar.keresztnev_f
4. utcanevek = magyar.utca
5. telelpülésnevek= magyar.telepules
6. vármegyék nevei = magyar.megye
7. folyók nevei = magyar.folyo
8. a hét napjai = magyar.nap
9. az év hónapjai = magyar.honap

## Description
1. last names =  magyar.vezeteknev
2. female first names = magyar.keresztnev_n
3. male first names  = magyar.keresztnev_f
4. street names = magyar.utca
5. city names = magyar.telepules
6. names of counties = magyar.megye
7. names of rivers = magyar.folyo
8. he days of the week = magyar.nap
9. the months of the year = magyar.honap
## Használat:

 Főként véletlengenerátorok kiegészítőjeként ajánlom
 
I recommend it mainly as a supplement to random number generators. 
       
             random.choice
telepulesek = random.choices(magyar.telepules, k=25)


## Szerző

* Név: Nagy BÉLa
* E-mail:nagy.bela.budapest@gmail.com

## Licenc

Oktatási célra készült, szabadon használható